aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorJustin Berger <j.david.berger@gmail.com>2018-04-10 23:44:36 -0600
committerJustin Berger <j.david.berger@gmail.com>2018-04-10 23:44:36 -0600
commit30cfb87ec0d95e0cb8a671cf8f2327b4204927ed (patch)
tree6f35a37400ff9f341c17e6cf57da73bc5a260363 /include
parent0653df1da7364e75953eea85e92d23f2b41480be (diff)
downloadlibsurvive-30cfb87ec0d95e0cb8a671cf8f2327b4204927ed.tar.gz
libsurvive-30cfb87ec0d95e0cb8a671cf8f2327b4204927ed.tar.bz2
Renamed api; fixed various warnings
Diffstat (limited to 'include')
-rw-r--r--include/libsurvive/survive_api.h104
1 files changed, 52 insertions, 52 deletions
diff --git a/include/libsurvive/survive_api.h b/include/libsurvive/survive_api.h
index fc4ce2c..64d1271 100644
--- a/include/libsurvive/survive_api.h
+++ b/include/libsurvive/survive_api.h
@@ -5,58 +5,58 @@
extern "C" {
#endif
- struct SurviveAsyncContext;
- typedef struct SurviveAsyncContext SurviveAsyncContext;
-
- /***
- * Initialize a new instance of an async context -- mirrors survive_init
- * @return Pointer to the async context
- */
- SURVIVE_EXPORT SurviveAsyncContext *survive_async_init(int argc, char *const *argv);
-
- /**
- * Close all devices and free all memory associated with the given context
- */
- SURVIVE_EXPORT void survive_async_close(SurviveAsyncContext* actx);
-
- /**
- * Start the background thread which processes various inputs and produces deliverable data like position.
- */
- SURVIVE_EXPORT void survive_async_start_thread(SurviveAsyncContext* actx);
-
- /**
- * @return true iff the background thread is still running
- */
- SURVIVE_EXPORT bool survive_async_is_running(SurviveAsyncContext *actx);
-
- struct SurviveAsyncObject;
- typedef struct SurviveAsyncObject SurviveAsyncObject;
-
- /**
- * Get the first known object. Note that this also includes lighthouses
- */
- SURVIVE_EXPORT const SurviveAsyncObject *survive_async_get_first_object(SurviveAsyncContext *actx);
- /**
- * Get the next known object from a current one.
- */
- SURVIVE_EXPORT const SurviveAsyncObject *survive_async_get_next_object(SurviveAsyncContext *actx,
- const SurviveAsyncObject *curr);
-
- /**
- * Gets the next object which has been updated since we last looked at it with this function
- */
- SURVIVE_EXPORT const SurviveAsyncObject *survive_async_get_next_updated(SurviveAsyncContext *actx);
-
- /**
- * Gets the pose of a given object
- */
- SURVIVE_EXPORT survive_timecode survive_async_object_get_latest_pose(const SurviveAsyncObject *sao,
- SurvivePose *pose);
-
- /**
- * Gets the null terminated name of the object.
- */
- SURVIVE_EXPORT const char *survive_async_object_name(const SurviveAsyncObject *sao);
+struct SurviveSimpleContext;
+typedef struct SurviveSimpleContext SurviveSimpleContext;
+
+/***
+ * Initialize a new instance of an simple context -- mirrors survive_init
+ * @return Pointer to the simple context
+ */
+SURVIVE_EXPORT SurviveSimpleContext *survive_simple_init(int argc, char *const *argv);
+
+/**
+ * Close all devices and free all memory associated with the given context
+ */
+SURVIVE_EXPORT void survive_simple_close(SurviveSimpleContext *actx);
+
+/**
+ * Start the background thread which processes various inputs and produces deliverable data like position.
+ */
+SURVIVE_EXPORT void survive_simple_start_thread(SurviveSimpleContext *actx);
+
+/**
+ * @return true iff the background thread is still running
+ */
+SURVIVE_EXPORT bool survive_simple_is_running(SurviveSimpleContext *actx);
+
+struct SurviveSimpleObject;
+typedef struct SurviveSimpleObject SurviveSimpleObject;
+
+/**
+ * Get the first known object. Note that this also includes lighthouses
+ */
+SURVIVE_EXPORT const SurviveSimpleObject *survive_simple_get_first_object(SurviveSimpleContext *actx);
+/**
+ * Get the next known object from a current one.
+ */
+SURVIVE_EXPORT const SurviveSimpleObject *survive_simple_get_next_object(SurviveSimpleContext *actx,
+ const SurviveSimpleObject *curr);
+
+/**
+ * Gets the next object which has been updated since we last looked at it with this function
+ */
+SURVIVE_EXPORT const SurviveSimpleObject *survive_simple_get_next_updated(SurviveSimpleContext *actx);
+
+/**
+ * Gets the pose of a given object
+ */
+SURVIVE_EXPORT survive_timecode survive_simple_object_get_latest_pose(const SurviveSimpleObject *sao,
+ SurvivePose *pose);
+
+/**
+ * Gets the null terminated name of the object.
+ */
+SURVIVE_EXPORT const char *survive_simple_object_name(const SurviveSimpleObject *sao);
#ifdef __cplusplus
}